@@ -6,7 +6,7 @@ from typing import List, Text, NoReturn
 from rasa.cli import SubParsersAction
 from rasa.cli.arguments import run as arguments
 import rasa.cli.utils
-import rasa.shared.utils.cli
+import rasa.shared.utils.cli  # noqa: F401
 from rasa.shared.constants import (
     DOCS_BASE_URL,
     DEFAULT_ENDPOINTS_PATH,
