@@ -3,7 +3,7 @@ import logging
 import os
 import sys
 from types import FrameType
-from typing import Any, Dict, List, NoReturn, Optional, TYPE_CHECKING, Text
+from typing import Any, Dict, List, Optional, TYPE_CHECKING, Text
 
 from rasa.shared.constants import DEFAULT_MODELS_PATH
 import rasa.shared.utils.cli
@@ -197,6 +197,7 @@ def payload_from_button_question(button_question: "Question") -> Text:
     return response
 
 
-def signal_handler(sig: int, frame: FrameType) -> NoReturn:
+def signal_handler(_: int, __: FrameType) -> None:
+    """Kills Rasa when OS signal is received."""
     print("Goodbye 👋")
     sys.exit(0)
