@@ -2,7 +2,7 @@ import argparse
 import asyncio
 import importlib.util
 import logging
-from multiprocessing import get_context
+from multiprocessing import get_context, Process
 import os
 import signal
 import sys
@@ -196,9 +196,10 @@ def _is_correct_event_broker(event_broker: EndpointConfig) -> bool:
     )
 
 
-def start_rasa_for_local_rasa_x(args: argparse.Namespace, rasa_x_token: Text) -> None:
+def start_rasa_for_local_rasa_x(
+    args: argparse.Namespace, rasa_x_token: Text
+) -> Process:
     """Starts the Rasa X API with Rasa as a background process."""
-
     credentials_path, endpoints_path = _get_credentials_and_endpoints_paths(args)
     endpoints = AvailableEndpoints.read_endpoints(endpoints_path)
 
