@@ -1,6 +1,6 @@
 import argparse
 import os
-from typing import Text
+from typing import Text, Union
 
 from rasa.shared.utils.cli import print_error
 import rasa.shared.nlu.training_data.loading
@@ -8,9 +8,23 @@ from rasa.nlu.utils import write_to_file
 
 
 def convert_training_data(
-    data_file: Text, out_file: Text, output_format: Text, language: Text
+    data_file: Union[list, Text], out_file: Text, output_format: Text, language: Text
 ) -> None:
-    if not os.path.exists(data_file):
+    """Convert training data.
+
+    Args:
+        data_file (Union[list, Text]): Path to the file or directory
+            containing Rasa data.
+        out_file (Text): File or existing path where to save
+            training data in Rasa format.
+        output_format (Text): Output format the training data
+            should be converted into.
+        language (Text): Language of the data.
+    """
+    if isinstance(data_file, list):
+        data_file = data_file[0]
+
+    if not os.path.exists(str(data_file)):
         print_error(
             "Data file '{}' does not exist. Provide a valid NLU data file using "
             "the '--data' argument.".format(data_file)
